@@ -21,11 +21,11 @@
 #' @name geom_interpolate_tern
 #' @rdname geom_interpolate_tern
 #' @export
-geom_interpolate_tern <- function(mapping = NULL, data = NULL, stat = "InterpolateTern",
-                         position = "identity", method='auto', lineend = "butt",
-                         linejoin = "round", linemitre = 1,
-                         na.rm = FALSE, show.legend = NA,
-                         inherit.aes = TRUE, formula=value~poly(x,y,degree=1),...) {
+geom_interpolate_tern <- function( mapping = NULL, data = NULL, stat = "InterpolateTern", position = "identity", 
+                                   lineend = "butt",linejoin = "round", linemitre = 1,
+                                   na.rm = FALSE, show.legend = NA,inherit.aes = TRUE, 
+                                   method='auto', formula=value~poly(x,y,degree=1),
+                                   ...) {
   layer(
     data        = data,
     mapping     = mapping,
@@ -51,8 +51,8 @@ geom_interpolate_tern <- function(mapping = NULL, data = NULL, stat = "Interpola
 #' @format NULL
 #' @usage NULL
 #' @export
-GeomInterpolateTern <- ggproto(
-  "GeomInterpolateTern", 
-  GeomPath,
-  default_aes = aes(colour = "#3366FF", size = 0.5, linetype = 1, alpha = NA)
+GeomInterpolateTern <- ggproto("GeomInterpolateTern", 
+                                GeomPath,
+                                default_aes = aes(colour = "#3366FF", size = 0.5, linetype = 1, alpha = NA)
+                                #draw_key = draw_key_path
 )
